@@ -1481,13 +1481,13 @@ var AST_NameMapping = DEFNODE("NameMapping", "foreign_name name", function AST_N
 
 var AST_Import = DEFNODE(
     "Import",
-    "imported_name imported_names module_name assert_clause",
+    "imported_name imported_names module_name attributes",
     function AST_Import(props) {
         if (props) {
             this.imported_name = props.imported_name;
             this.imported_names = props.imported_names;
             this.module_name = props.module_name;
-            this.assert_clause = props.assert_clause;
+            this.attributes = props.attributes;
             this.start = props.start;
             this.end = props.end;
         }
@@ -1500,7 +1500,7 @@ var AST_Import = DEFNODE(
             imported_name: "[AST_SymbolImport] The name of the variable holding the module's default export.",
             imported_names: "[AST_NameMapping*] The names of non-default imported variables",
             module_name: "[AST_String] String literal describing where this module came from",
-            assert_clause: "[AST_Object?] The import assertion"
+            attributes: "[AST_Object?] The import attributes (with {...})"
         },
         _walk: function(visitor) {
             return visitor._visit(this, function() {
@@ -1539,7 +1539,7 @@ var AST_ImportMeta = DEFNODE("ImportMeta", null, function AST_ImportMeta(props)
 
 var AST_Export = DEFNODE(
     "Export",
-    "exported_definition exported_value is_default exported_names module_name assert_clause",
+    "exported_definition exported_value is_default exported_names module_name attributes",
     function AST_Export(props) {
         if (props) {
             this.exported_definition = props.exported_definition;
@@ -1547,7 +1547,7 @@ var AST_Export = DEFNODE(
             this.is_default = props.is_default;
             this.exported_names = props.exported_names;
             this.module_name = props.module_name;
-            this.assert_clause = props.assert_clause;
+            this.attributes = props.attributes;
             this.start = props.start;
             this.end = props.end;
         }
@@ -1562,7 +1562,7 @@ var AST_Export = DEFNODE(
             exported_names: "[AST_NameMapping*?] List of exported names",
             module_name: "[AST_String?] Name of the file to load exports from",
             is_default: "[Boolean] Whether this is the default exported value of this module",
-            assert_clause: "[AST_Object?] The import assertion"
+            attributes: "[AST_Object?] The import attributes"
         },
         _walk: function (visitor) {
             return visitor._visit(this, function () {
@@ -2271,6 +2271,24 @@ var AST_Class = DEFNODE("Class", "name extends properties", function AST_Class(p
             }
         });
     },
+    is_self_referential: function() {
+        const this_id = this.name && this.name.definition().id;
+        let found = false;
+        let class_this = true;
+        this.visit_nondeferred_class_parts(new TreeWalker((node, descend) => {
+            if (found) return true;
+            if (node instanceof AST_This) return (found = class_this);
+            if (node instanceof AST_SymbolRef) return (found = node.definition().id === this_id);
+            if (node instanceof AST_Lambda && !(node instanceof AST_Arrow)) {
+                const class_this_save = class_this;
+                class_this = false;
+                descend();
+                class_this = class_this_save;
+                return true;
+            }
+        }));
+        return found;
+    },
 }, AST_Scope /* TODO a class might have a scope but it's not a scope */);
 
 var AST_ClassProperty = DEFNODE("ClassProperty", "static quote", function AST_ClassProperty(props) {
