@@ -2,6 +2,7 @@
 import "source-map-support/register.js";
 import path from "path";
 import fs from "fs";
+import child_process from "child_process";
 import assert from "assert";
 import semver from "semver";
 import { fileURLToPath } from "url";
@@ -29,7 +30,7 @@ var failed_files = {};
 var minify_options = JSON.parse(fs.readFileSync(path.join(__dirname, "ufuzz.json"), 'utf-8')).map(JSON.stringify);
 
 const already_logged = new Set()
-run_compress_tests().catch(e => {
+try_run_compress_tests_in_parallel().catch(e => {
     console.error(e);
     process.exit(1);
 });
@@ -50,8 +51,8 @@ function log(test, ...args) {
     console.log("%s", txt);
 }
 
-function log_directory(dir) {
-    log(null, "*** Entering [{dir}]", { dir: dir });
+function log_directory(dir, extra = '') {
+    log(null, "*** Entering [{dir}]{extra}", { dir, extra });
 }
 
 function log_test(test) {
@@ -61,7 +62,18 @@ function log_test(test) {
     log(null, "    {file}", { file: test.file });
 }
 
-function find_test_files(dir) {
+function log_test_result({ test_failures, failed_files, test_cases }) {
+    if (test_failures) {
+        console.error("\n!!! Failed " + test_failures + " test cases.");
+        console.error("!!! " + Object.keys(failed_files).join(", "));
+        process.exit(1);
+    } else {
+        console.log("\nPassed " + test_cases + " test cases.");
+    }
+}
+
+function find_test_files() {
+    var dir = test_directory("compress");
     var files = fs.readdirSync(dir).filter(function(name) {
         return /\.js$/i.test(name);
     });
@@ -78,35 +90,209 @@ function test_directory(dir) {
     return path.resolve(tests_dir, dir);
 }
 
-function as_toplevel(input, mangle_options) {
-    if (!(input instanceof AST.AST_BlockStatement))
-        throw new Error("Unsupported input syntax");
-    for (var i = 0; i < input.body.length; i++) {
-        var stat = input.body[i];
-        if (stat instanceof AST.AST_SimpleStatement && stat.body instanceof AST.AST_String)
-            input.body[i] = new AST.AST_Directive(stat.body);
-        else break;
+function as_template_string_code(ast) {
+    if (
+        ast instanceof AST.AST_SimpleStatement
+        && ast.body instanceof AST.AST_TemplateString
+        && ast.body.segments.length === 1
+    ) {
+        return ast.body.segments[0].value;
+    }
+}
+
+function as_toplevel(test, input, mangle_options) {
+    var toplevel, tpl_input;
+    if (input instanceof AST.AST_BlockStatement) {
+        for (var i = 0; i < input.body.length; i++) {
+            var stat = input.body[i];
+            if (stat instanceof AST.AST_SimpleStatement && stat.body instanceof AST.AST_String)
+                input.body[i] = new AST.AST_Directive(stat.body);
+            else break;
+        }
+        var toplevel = new AST.AST_Toplevel(input);
+    } else if (
+        (tpl_input = as_template_string_code(input))
+    ) {
+        try {
+            var toplevel = parse(tpl_input);
+        } catch (error) {
+            log(test, "!!! Cannot parse input\n---INPUT---\n{input}\n--PARSE ERROR--\n{error}\n\n", {
+                input: tpl_input,
+                error,
+            });
+            return null;
+        }
+    } else {
+        log(test, "Unsupported input syntax");
+        return null;
     }
-    var toplevel = new AST.AST_Toplevel(input);
     toplevel.figure_out_scope(mangle_options);
     return toplevel;
 }
 
-async function run_compress_tests() {
+async function try_run_compress_tests_in_parallel() {
+    if (!await run_compress_tests_in_parallel()) {
+        run_compress_tests();
+    }
+}
+
+// If possible, use worker threads to run tests in parallel
+async function run_compress_tests_in_parallel() {
+    if (process.env.TEST_NO_WORKER) {
+        return undefined;
+    }
+    const test_files = find_test_files();
+    if (test_files.length < 2) {
+        return undefined; // Run this in series
+    }
+
+    if (process.send) {
+        // We are in the fork!
+
+        // do one test, ask for more, repeat
+        process.on('message', async (filename) => {
+            try {
+                const test_result = await run_compress_tests([filename], true);
+                process.send({ test_result }); // request work
+            } catch (error) {
+                console.error(error);
+                process.exit(1);
+            }
+        });
+
+        process.send({}); // request the first piece
+
+        return true;
+    }
+
+    const test_files_work = test_files.map(filename => ({
+        filename,
+        output: [],
+        test_result: null,
+        done: false,
+    }));
+
+    function proxy_output() {
+        const proxy = ([ stream, data ]) => {
+            process[stream].write(data);
+        };
+
+        for (const task of test_files_work) {
+            if (task.output.length) {
+                task.output.forEach(proxy);
+                task.output = []
+            }
+
+            if (!task.done) {
+                // This is the last task in series. Live-log it!
+                // task.output = { length: 0, push: proxy };
+                return;
+            }
+        }
+    }
+
+    async function start_worker() {
+        let fork = child_process.fork(__filename, [], {
+            stdio: [null, 'pipe', 'pipe', 'ipc'],
+        });
+
+        let work_promise = new Promise((resolve, reject) => {
+            let current_task
+            let get_task = () => test_files_work
+                .find(task => task.filename === current_task)
+
+            fork.on("message", ({ test_result }) => {
+                proxy_output();
+
+                // absent in the first message
+                if (test_result) {
+                    get_task().test_result = test_result;
+                    get_task().done = true;
+                }
+
+                current_task = test_files.shift();
+                if (current_task) {
+                    fork.send(current_task);
+                } else {
+                    resolve();
+                }
+            });
+            fork.stdout.on('data', data => {
+                get_task().output.push(['stdout', data])
+                proxy_output();
+            });
+            fork.stderr.on('data', data => {
+                get_task().output.push(['stderr', data])
+                proxy_output();
+            });
+            fork.on('error', reject);
+            fork.on('disconnect', reject);
+        });
+
+        try {
+            return await work_promise;
+        } finally {
+            fork.kill();
+        }
+    }
+
+    const n_workers = Math.min(test_files.length, 2);
+    const workers_promises = Promise.all(
+        Array.from({ length: n_workers }, start_worker),
+    );
+
+    log_directory("test/compress", " with " + n_workers + " workers");
+
+    // Join all
+    try {
+        await workers_promises;
+    } catch (error) {
+        console.error('!!! Fatal error while running tests');
+
+        process.exitCode = 1;
+        return true;
+    }
+
+    const joint_result = test_files_work
+        .map(t => t.test_result)
+        .reduce(
+            (a, b) => {
+                if (b) {
+                    a.test_cases += b.test_cases;
+                    a.test_failures += b.test_failures;
+                    Object.assign(a.failed_files, b.failed_files);
+                }
+                return a;
+            },
+            {
+                test_cases: 0,
+                test_failures: 0,
+                failed_files: {},
+            }
+        );
+
+    log_test_result(joint_result);
+
+    return true;
+}
+
+async function run_compress_tests(test_files, in_child_process) {
     var test_failures = 0;
     var test_cases = 0;
     const enable_js_sandbox =
         !process.env.TEST_NO_SANDBOX && semver.satisfies(process.version, ">=16")
 
     var dir = test_directory("compress");
-    log_directory("test/compress");
-    var files = find_test_files(dir);
+    if (!in_child_process) log_directory("test/compress");
+    var files = test_files || find_test_files();
     async function test_file(file) {
         async function test_case(test) {
             var output_options = test.beautify || test.format || {};
             var expect;
             if (test.expect) {
-                expect = make_code(as_toplevel(test.expect, test.mangle), output_options);
+                let toplevel = as_toplevel(test, test.expect, test.mangle);
+                if (!toplevel) return false;
+                expect = make_code(toplevel, output_options);
             } else {
                 expect = test.expect_exact;
             }
@@ -114,53 +300,47 @@ async function run_compress_tests() {
                 log(test, "!!! Test cannot have an `expect_error` with other expect clauses\n", {});
                 return false;
             }
-            if (test.input instanceof AST.AST_SimpleStatement
-                && test.input.body instanceof AST.AST_TemplateString) {
-                if (test.input.body.segments.length == 1) {
-                    try {
-                        var input = parse(test.input.body.segments[0].value);
-                    } catch (ex) {
-                        if (!test.expect_error) {
-                            log(test, "!!! Test is missing an `expect_error` clause\n", {});
-                            return false;
-                        }
-                        if (test.expect_error instanceof AST.AST_SimpleStatement
-                        && test.expect_error.body instanceof AST.AST_Object) {
-                            var expect_error = eval("(" + test.expect_error.body.print_to_string() + ")");
-                            var ex_normalized = JSON.parse(JSON.stringify(ex));
-                            ex_normalized.name = ex.name;
-                            for (var prop in expect_error) {
-                                if (prop == "name" || HOP(expect_error, prop)) {
-                                    if (expect_error[prop] != ex_normalized[prop]) {
-                                        log(test, "!!! Failed `expect_error` property `{prop}`:\n\n---expect_error---\n{expect_error}\n\n---ACTUAL exception--\n{actual_ex}\n\n", {
-                                            prop: prop,
-                                            expect_error: JSON.stringify(expect_error, null, 2),
-                                            actual_ex: JSON.stringify(ex_normalized, null, 2),
-                                        });
-                                        return false;
-                                    }
-                                }
-                            }
-                            return true;
-                        }
-                        log(test, "!!! Test `expect_error` clause must be an object literal\n---expect_error---\n{expect_error}\n\n", {
-                            expect_error: test.expect_error.print_to_string(),
-                        });
+            var bad_input = as_template_string_code(test.bad_input);
+            if (bad_input != null) {
+                try {
+                    var input = parse(bad_input);
+                } catch (ex) {
+                    if (!test.expect_error) {
+                        log(test, "!!! Test is missing an `expect_error` clause\n", {});
                         return false;
                     }
-                    var input_code = make_code(input, output_options);
-                    var input_formatted = test.input.body.segments[0].value;
-                } else {
-                    log(test, "!!! Test input template string cannot use unescaped ${} expressions\n---INPUT---\n{input}\n\n", {
-                        input: test.input.body.print_to_string(),
+                    if (test.expect_error instanceof AST.AST_SimpleStatement
+                    && test.expect_error.body instanceof AST.AST_Object) {
+                        var expect_error = eval("(" + test.expect_error.body.print_to_string() + ")");
+                        var ex_normalized = JSON.parse(JSON.stringify(ex));
+                        ex_normalized.name = ex.name;
+                        for (var prop in expect_error) {
+                            if (prop == "name" || HOP(expect_error, prop)) {
+                                if (expect_error[prop] != ex_normalized[prop]) {
+                                    log(test, "!!! Failed `expect_error` property `{prop}`:\n\n---expect_error---\n{expect_error}\n\n---ACTUAL exception--\n{actual_ex}\n\n", {
+                                        prop: prop,
+                                        expect_error: JSON.stringify(expect_error, null, 2),
+                                        actual_ex: JSON.stringify(ex_normalized, null, 2),
+                                    });
+                                    return false;
+                                }
+                            }
+                        }
+                        return true;
+                    }
+                    log(test, "!!! Test `expect_error` clause must be an object literal\n---expect_error---\n{expect_error}\n\n", {
+                        expect_error: test.expect_error.print_to_string(),
                     });
                     return false;
                 }
+                var input_code = make_code(input, output_options);
+                var input_formatted = bad_input;
             } else if (test.expect_error) {
-                log(test, "!!! Test cannot have an `expect_error` clause without a template string `input`\n", {});
+                log(test, "!!! Test cannot have an `expect_error` clause without a template string `bad_input`\n", {});
                 return false;
             } else {
-                var input = as_toplevel(test.input, test.mangle);
+                var input = as_toplevel(test, test.input, test.mangle);
+                if (!input) return false;
                 var input_code = make_code(input, output_options);
                 var input_formatted = make_code(test.input, {
                     ecma: 2015,
@@ -320,13 +500,12 @@ async function run_compress_tests() {
             break;
         }
     }
-    if (test_failures) {
-        console.error("\n!!! Failed " + test_failures + " test cases.");
-        console.error("!!! " + Object.keys(failed_files).join(", "));
-        process.exit(1);
-    } else {
-        console.log("\nPassed " + test_cases + " test cases.");
+    const result = { test_failures, test_cases, failed_files };
+    if (!in_child_process) {
+        log_test_result(result);
     }
+
+    return result;
 }
 
 function parse_test(file) {
@@ -422,12 +601,14 @@ function parse_test(file) {
                 assert.ok(
                     [
                         "input",
+                        "bad_input",
                         "prepend_code",
                         "expect",
                         "expect_error",
                         "expect_exact",
                         "expect_stdout",
                         "node_version",
+                        "no_mozilla_ast",
                         "reminify",
                     ].includes(label.name),
                     tmpl("Unsupported label {name} [{line},{col}]", {
@@ -464,6 +645,8 @@ function parse_test(file) {
                     }
                 } else if (label.name === "prepend_code") {
                     test[label.name] = read_string(stat);
+                } else if (label.name === "no_mozilla_ast") {
+                    test[label.name] = read_boolean(stat);
                 } else {
                     test[label.name] = stat;
                 }
@@ -476,6 +659,8 @@ function parse_test(file) {
 }
 
 function make_code(ast, options) {
+    var code_verbatim = as_template_string_code(ast);
+    if (code_verbatim != null) return code_verbatim;
     var stream = OutputStream(options);
     ast.print(stream);
     return stream.get();
