@@ -18,6 +18,7 @@ big_int_hex: {
         0xfabn
     }
     expect_exact: "0x20n;0xfabn;"
+    no_mozilla_ast: true
 }
 
 regression_big_int_hex_lower_with_e: {
@@ -25,6 +26,7 @@ regression_big_int_hex_lower_with_e: {
         0xaefen;
     }
     expect_exact: "0xaefen;"
+    no_mozilla_ast: true
 }
 
 big_int_binary: {
@@ -32,6 +34,7 @@ big_int_binary: {
         0b101n
     }
     expect_exact: "0b101n;"
+    no_mozilla_ast: true
 }
 
 big_int_octal: {
@@ -39,10 +42,11 @@ big_int_octal: {
         0o7n
     }
     expect_exact: "0o7n;"
+    no_mozilla_ast: true
 }
 
 big_int_no_e: {
-    input: `1e3n`
+    bad_input: `1e3n`
     expect_error: ({
         name: "SyntaxError",
         message: "Invalid or unexpected token"
@@ -50,7 +54,7 @@ big_int_no_e: {
 }
 
 big_int_bad_digits_for_base: {
-    input: `0o9n`
+    bad_input: `0o9n`
     expect_error: ({
         name: "SyntaxError",
         message: "Invalid or unexpected token"
@@ -58,17 +62,34 @@ big_int_bad_digits_for_base: {
 }
 
 big_int_math: {
+    options = {
+        defaults: true
+    }
+    input: {
+        console.log({
+            sum: 10n + 15n,
+            exp: 2n ** 3n,
+            sub: 1n - 3n,
+            mul: 5n * 5n,
+            div: 15n / 5n,
+        });
+    }
+    expect_exact: "console.log({sum:25n,exp:8n,sub:-2n,mul:25n,div:3n});"
+    expect_stdout: true
+}
+
+big_int_math_counter_examples: {
     node_version = ">= 12"
     options = {
         defaults: true
     }
     input: {
-        const sum = 10n + 15n;
-        const exp = 5n ** 10n;
-        const sub = 1n - 3n;
-        const mul = 5n * 5n;
-        const div = 15n / 5n;
-        const regular_number = 1 * 10;
+        console.log({
+            mixing_types: 1 * 10n,
+            bad_shift: 1n >>> 0n,
+            bad_div: 1n / 0n,
+        });
     }
-    expect_exact: "const sum=10n+15n,exp=5n**10n,sub=1n-3n,mul=5n*5n,div=15n/5n,regular_number=10;"
+    expect_exact: "console.log({mixing_types:1*10n,bad_shift:1n>>>0n,bad_div:1n/0n});"
+    expect_stdout: true
 }
