@@ -158,6 +158,136 @@ or: {
     }
 }
 
+bitwise: {
+    options = {
+        evaluate: true,
+        side_effects: true,
+        booleans: true,
+        comparisons: true,
+    }
+    input: {
+        const any = {}
+
+        const test1 = (bar & 1) | 0
+        const test1_rev = 0 | (bar & 1)
+        const test2 = (bar & 1) & ~0
+        const test2_rev = ~0 & (bar & 1)
+        const test3 = (bar & 1) ^ 0
+        const test3_rev = 0 ^ (bar & 1)
+        const test4 = bar ^ -1
+        const test4_rev = -1 ^ bar
+        const test5 = ~(bar ^ baz)
+        const test6 = (bar | 1) | 0
+        const test7 = (bar | 1) & 2
+        const test7_rev = (1 | bar) & 2
+        const test8 = (bar | 1) & 3
+        const test9 = any | ~0
+        const test9_rev = ~0 | any
+        const test10 = any & 0
+        const test10_rev = 0 & any
+        const test11 = (bar & 7) !== 0
+        const test11_rev = 0 !== (bar & 7)
+        const test11_2 = (bar & 7) === 0
+        const test11_2_rev = 0 === (bar & 7)
+        if ((a & b) !== 0) c()
+        const test12 = (bar & 7) !== 7
+        const test12_rev = 7 == (bar & 7)
+
+        const test13 = ~~bar | 0;
+        const test13_2 = ~~~bar;
+        const test13_3 = ~~(bar | baz);
+
+        const test14 = (bar | baz) >> 0;
+    }
+    expect: {
+        const any = {};
+
+        const test1 = bar & 1
+        const test1_rev = bar & 1
+        const test2 = bar & 1
+        const test2_rev = bar & 1
+        const test3 = bar & 1
+        const test3_rev = bar & 1
+        const test4 = ~bar
+        const test4_rev = ~bar
+        const test5 = bar ^ ~baz
+        const test6 = 1 | bar
+        const test7 = 2 & bar
+        const test7_rev = 2 & bar
+        const test8 = bar & 3 | 1
+        const test9 = -1
+        const test9_rev = -1
+        const test10 = 0
+        const test10_rev = 0
+        const test11 = !!(bar & 7)
+        const test11_rev = !!(bar & 7)
+        const test11_2 = !(bar & 7)
+        const test11_2_rev = !(bar & 7)
+        if (a & b) c()
+        const test12 = !!(7 & ~bar)
+        const test12_rev = !(7 & ~bar)
+
+        const test13 = bar | 0;
+        const test13_2 = ~bar;
+        const test13_3 = bar | baz;
+
+        const test14 = bar | baz;
+    }
+}
+
+bitwise_2: {
+    options = {
+        evaluate: true,
+        side_effects: true,
+        booleans: true,
+        comparisons: true,
+    }
+    input: {
+        const any = {}
+
+        const test1 = (bar | 0) & 1
+        const test1_rev = 1 & (bar | 0)
+        const test2 = (bar & ~0) & 1
+        const test2_rev = 1 & (bar & ~0)
+        const test3 = (bar ^ 0) ^ baz
+        const test5 = ~(bar ^ ~baz)
+        const test5_2 = ~(~bar ^ baz)
+        const test5_3 = ~bar ^ ~baz
+
+        const same = globalThis.same;
+        const test6 = same & same
+        const test6_2 = same | same
+        const test6_3 = same ^ same
+    }
+    expect: {
+        const any = {};
+
+        const test1 = bar & 1
+        const test1_rev = 1 & bar
+        const test2 = bar & 1
+        const test2_rev = 1 & bar
+        const test3 = bar ^ baz
+        const test5 = bar ^ baz
+        const test5_2 = bar ^ baz
+        const test5_3 = bar ^ baz
+
+        const same = globalThis.same;
+        const test6 = 0|same
+        const test6_2 = 0|same
+        const test6_3 = 0
+    }
+}
+
+bitwise_regression: {
+    options = {
+        evaluate: true,
+    }
+    input: {
+        console.log((id(0xff00ff) | id(0x00ff00)) & 0x3fff)
+    }
+    expect_stdout: "16383"
+}
+
 unary_prefix: {
     options = {
         evaluate: true,
@@ -1790,6 +1920,27 @@ issue_399: {
     }
 }
 
+issue_t1458: {
+    options = {
+        unsafe: true,
+        pure_getters: true
+    }
+    input: {
+        global.z = null
+        var a = z?.j.toString();
+        var b = z?.toString();
+        var c = z?.[0].toString();
+        global.z = [null]
+        var d = z[0]?.toString();
+        global.z = () => null
+        var e = z()?.toString();
+        var f = z()?.x.toString();
+        var g = z()?.x.toString().x;
+        console.log(typeof a, typeof b, typeof c, typeof d, typeof e, typeof f, typeof g);
+    }
+    expect_stdout: "undefined undefined undefined undefined undefined undefined undefined"
+}
+
 null_conditional_chain_eval: {
     options = {
         evaluate: true,
@@ -1821,7 +1972,7 @@ null_conditional_chain_eval_2: {
         null.deep?.maybe_call?.(3)
     }
     expect: {
-        null.deep?.unused
+        null.deep
         null.deep?.[side_effect()]
         null.deep?.unused.but_might_throw
         null.deep?.call(1)
