@@ -19,10 +19,10 @@ comparison_with_undefined: {
         void 0 !== a;
     }
     expect: {
-        null == a;
-        null != a;
-        void 0 === a;
-        void 0 !== a;
+        a == null;
+        a != null;
+        a === void 0;
+        a !== void 0;
 
         null == a;
         null != a;
